@@ -1,8 +1,7 @@
-import configparser
 from pathlib import Path
 from typing import Union
 
-import yaml
+import toml
 from pika import PlainCredentials, ConnectionParameters
 
 
@@ -20,25 +19,14 @@ class RabbitConfig:
         self.params = ConnectionParameters(host, port, '/', self.credentials)
 
     @staticmethod
-    def from_yaml_file(path: Union[Path, str]) -> 'RabbitConfig':
+    def from_toml_file(path: Union[Path, str]) -> 'RabbitConfig':
         if isinstance(path, str):
             path = Path(path)
-        data = yaml.safe_load(path.read_text())
-        return RabbitConfig._from_dict(data)
+        data = toml.load(path)['rabbit']
+        return RabbitConfig.from_dict(data)
 
     @staticmethod
-    def from_ini_file(path: Union[Path, str]) -> 'RabbitConfig':
-        if isinstance(path, str):
-            path = Path(path)
-        config = configparser.ConfigParser()
-        config.read(path)
-        rabbit_config = config['rabbit']
-        return RabbitConfig._from_dict(rabbit_config)
-
-    @staticmethod
-    def _from_dict(
-            dictionary: Union[dict[str, any], configparser.SectionProxy]
-    ) -> 'RabbitConfig':
+    def from_dict(dictionary: dict[str, any]) -> 'RabbitConfig':
         host = dictionary['host']
         port = int(dictionary['port'])
         exchange_name = dictionary['exchange_name']
